summaryrefslogtreecommitdiffstats
path: root/systemsettings/kcmultiwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'systemsettings/kcmultiwidget.h')
-rw-r--r--systemsettings/kcmultiwidget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/systemsettings/kcmultiwidget.h b/systemsettings/kcmultiwidget.h
index 78edfb4..181ba4e 100644
--- a/systemsettings/kcmultiwidget.h
+++ b/systemsettings/kcmultiwidget.h
@@ -90,8 +90,8 @@ public:
* used for creating the module. It will be added
* to the list of modules the dialog will show.
*
* @param tqparentmodulenames The names of the modules that should appear as
* tqparents in the TreeList. Look at the
* KDialogBase::addPage documentation for more info
* on this.
*
@@ -99,7 +99,7 @@ public:
* in the module appearing outside the dialog.
**/
void addModule(const KCModuleInfo& moduleinfo, TQStringList
- tqparentmodulenames = TQStringList(), bool withfallback=false);
+ parentmodulenames = TQStringList(), bool withfallback=false);
/**
* @return the current module that is being shown.
@@ -90,8 +90,8 @@ public:
* to the list of modules the dialog will show.
*
- * @param tqparentmodulenames The names of the modules that should appear as
- * tqparents in the TreeList. Look at the
+ * @param parentmodulenames The names of the modules that should appear as
+ * parents in the TreeList. Look at the
* KDialogBase::addPage documentation for more info
* on this.